@@ -1,10 +1,12 @@
 
+from . import decorators
 from .checker import (
     AsyncChecker,
     BaseChecker,
     BazelChecker,
     Checker,
     CheckerSummary)
+from .decorators import preload
 
 
 __all__ = (
@@ -12,4 +14,6 @@ __all__ = (
     "BaseChecker",
     "BazelChecker",
     "Checker",
-    "CheckerSummary")
+    "CheckerSummary",
+    "decorators",
+    "preload")
